=========================
MasterCard file utilities
=========================

.. image:: https://img.shields.io/travis/adelosa/mciutil.svg
        :target: https://travis-ci.org/adelosa/mciutil

.. image:: https://img.shields.io/pypi/v/mciutil.svg
        :target: https://pypi.python.org/pypi/mciutil

.. image:: https://coveralls.io/repos/adelosa/mciutil/badge.svg?branch=feature%2Fupdate-travis-ci-settings&service=github
        :target: https://coveralls.io/github/adelosa/mciutil?branch=feature%2Fupdate-travis-ci-settings


Set of command line utilities to work with various MasterCard files.

* Free software: BSD license
* Documentation: https://mciutil.readthedocs.org.

Features
--------

Provides the following command line utilities:

* paramconv: Utility for working with MasterCard MPE parameter extract files
* mideu: Utility for working with MasterCard IPM files
